# CDK Resources for Chime

![Experimental](https://img.shields.io/badge/experimental-important.svg?style=for-the-badge)

Deploy Chime resources with CDK

## Usage

See [example/lib/cdk-chime-resources-example.ts](example/lib/cdk-chime-resources-example.ts) for a complete example.

CDK Resources for Chime supports the creation of Chime resources within a CDK using a Custom Resource. These resources will be created automatically and can be used together to build an Amazon Chime PSTN Audio application.

### Phone Number Creation

```python
const phoneNumber = new chime.ChimePhoneNumber(this, 'phoneNumber', {
  phoneState: 'IL',
  phoneNumberType: chime.PhoneNumberType.LOCAL,
  phoneProductType: chime.PhoneProductType.SMA,
});
```

The phone number created will be a `LOCAL` number for use with `SMA` from a pool of available numbers in Illinois. Other search option are available that will return a single phone number based on the criteria provided.

### SIP Media Application Creation

```python
const sipMediaApp = new chime.ChimeSipMediaApp(this, 'sipMediaApp', {
  region: this.region,
  endpoint: smaHandler.functionArn,
});
```

The SIP media application created will use the smaHandler referenced by the endpoint in the same region the CDK is being deployed in. The SIP media application must be created in the same region as the associated Lambda endpoint and must be in `us-east-1` or `us-west-2`.

```python
const sipRule = new chime.ChimeSipRule(this, 'sipRule', {
  region: this.region,
  triggerType: chime.TriggerType.TO_PHONE_NUMBER,
  triggerValue: phoneNumber.phoneNumber,
  priority: 1,
  sipMediaApplicationId: sipMediaApp.sipMediaAppId,
});
```

The SIP rule will assocaite the previously created phone number with the previously created SIP media application. The SIP rule can be associated with either an E.164 number or Amazon Chime Voice Connector URI. If the TriggerType is `TO_PHONE_NUMBER`, the TriggerValue must be an E.164 number. If the TriggerType is `REQUEST_URI_HOSTNAME`, the TriggerValue must be an Amazon Chime Voice Connector URI. A priority must be assigned with a value between 1 and 25 inclusive. A sipMediaApplicationId is required. This will associate the trigger to the SIP media application and associated Lambda.

### Voice Connector Creation

Using a phone number created with Product Type of VC:

```python
const voiceConnector = new chime.ChimeVoiceConnector(this, 'voiceConnector', {
  terminationCidrs: ['198.51.100.10/32'],
  originationIps: ['198.51.100.10'],
  streaming: true,
  encryption: true,
  notificationTargets: [chime.NotificationTargetType.EVENTBRIDGE],
});
```

This will create an Amazon Chime Voice Connector with specified options.

```python
voiceConnectorPhone.associateWithVoiceConnector(voiceConnector);
```

This will assocaite the previously created phone number with the voice connector.

## Not Supported Yet

This is a work in progress.

Features that are not supported yet:

* [ ] Amazon Chime Voice Connector Groups
* [ ] Multiple routes and weights for Voice Connectors
* [ ] Mutliple SIP media applications per SIP rule

## Contributing

See [CONTRIBUTING](CONTRIBUTING.md) for more information.

## License

This project is licensed under the Apache-2.0 License.
