import { Construct } from 'constructs';
/**
 * @stability stable
 */
export declare enum NotificationTargetType {
    /**
     * @stability stable
     */
    EVENTBRIDGE = "EventBridge",
    /**
     * @stability stable
     */
    SNS = "SNS",
    /**
     * @stability stable
     */
    SQS = "SQS"
}
/**
 * Props for `SipMediaApplication`.
 *
 * @stability stable
 */
export interface VoiceConnectorProps {
    /**
     * region for SipMediaApplication(required) - Must us-east-1 or us-west-2 and in the same region as the SipMediaApplication Lambda handler.
     *
     * @default - same region as stack deployment
     * @stability stable
     */
    readonly region?: string;
    /**
     * termination IP for VoiceConnector (optional).
     *
     * @default - none
     * @stability stable
     */
    readonly terminationCidrs?: Array<string>;
    /**
     * Calling Regions for VoiceConnector (optional).
     *
     * @default - ['US']
     * @stability stable
     */
    readonly callingRegions?: Array<string>;
    /**
     * origination CIDRs for VoiceConnector (optional).
     *
     * @default - none
     * @stability stable
     */
    readonly originationIps?: Array<string>;
    /**
     * name for VoiceConnector.
     *
     * @default - unique ID for resource
     * @stability stable
     */
    readonly name?: string;
    /**
     * Encryption boolean for VoiceConnector.
     *
     * @default - False
     * @stability stable
     */
    readonly encryption?: boolean;
    /**
     * Streaming boolean for VoiceConnector.
     *
     * @default - False
     * @stability stable
     */
    readonly streaming?: boolean;
    /**
     * Streaming data retention for VoiceConnector.
     *
     * @default - 0
     * @stability stable
     */
    readonly dataRetention?: number;
    /**
     * Streaming data retention for VoiceConnector.
     *
     * @default - 0
     * @stability stable
     */
    readonly notificationTargets?: Array<NotificationTargetType>;
}
/**
 * @stability stable
 */
export declare class ChimeVoiceConnector extends Construct {
    /**
     * @stability stable
     */
    readonly voiceConnectorId: string;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: VoiceConnectorProps);
}
